
function demo_2019_weights(RBF_type)
   
%------------------------------------------------------------------
% OBJECT:
% Integration over rectangles by means of RBF, by cubature weights.
%------------------------------------------------------------------

warning off;

%------------------------------------------------------------------
% Define number of radial centers.
%------------------------------------------------------------------
N=1000;

%------------------------------------------------------------------
% 1=MQ, 2=G, 3=IMQ, 4=W2, 5=TPS
%------------------------------------------------------------------
if nargin < 1, RBF_type=1; end

%------------------------------------------------------------------
% RBF scale. Default: 1
%------------------------------------------------------------------
RBF_scale=1+rand(N,1);

%------------------------------------------------------------------
% 1: z=0.0001*abs(6-x.^2-y.^2).^2;
% 2: z=peaks(x,y);
% 3: z=x.^2+y.^2;
% 4: z=exp(-x.^2-y.^2);
% 5: z=exp(-x.^2-5*y.^2);
% 6: z=ones(size(x));
% 7: z=cos(x+y);
% 8: z=x+y;
% 9: k=5; z=1+cos(k*(x+y));
%------------------------------------------------------------------
f_type=4;

%------------------------------------------------------------------
% Rectangle vertices:
% * vertices=[a c; b c; b d; a d];
%------------------------------------------------------------------
a=-1; b=1; c=-1; d=1;

%------------------------------------------------------------------
% Ref cubature tolerance
%------------------------------------------------------------------
tolref=10^(-12);

%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%                   MAIN PROGRAM STARTS HERE
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

%------------------------------------------------------------------
% Define "Domain", by points.
%------------------------------------------------------------------
vertices=[a c; b c; b d; a d];

x=rand(N,1); y=rand(N,1);
points=[a+(b-a)*x c+(d-c)*y];
f=fct2D(x,y,f_type);
values=feval(f,points(:,1),points(:,2));

%------------------------------------------------------------------
% RBF weights computation.
%------------------------------------------------------------------
tic;
weights=RBF_weights(vertices,points,RBF_type,RBF_scale);
cubCPU=toc;

cub=weights'*values;

%------------------------------------------------------------------
% Exact value.
%------------------------------------------------------------------
tic;
IR = integral2(f,a,b,c,d,'AbsTol',tolref,'RelTol',tolref);
refCPU=toc;

%------------------------------------------------------------------
% Statistics
%------------------------------------------------------------------

fprintf('\n \n \t *** STATISTICS *** \n');

fprintf('\n \t FUNCTION TYPE: %2.0f',f_type);
fprintf('\n \t RBF TYPE     : %2.0f',RBF_type);
if isscalar(RBF_scale) == 1
fprintf('\n \t RBF SCALE    : %1.5e',RBF_scale);
else
    fprintf('\n \t RBF SCALE    : VARIABLE');
end
fprintf('\n \t NODES CARDIN.: %4.0f',N);
fprintf('\n \n \t CUBATURE RES.: %1.15e',cub);
fprintf('\n \t EXACT VALUE  : %1.15e',IR);
ae=abs(IR-cub);
fprintf('\n \n \t * ABSOLUTE ERR.: %1.3e',ae);
if abs(IR) > 0
    fprintf('\n \t * RELATIVE ERR.: %1.3e',ae/abs(IR));
end
fprintf('\n \n \t ** REF.CUB.TOL: %1.5e',tolref)
fprintf('\n \n \t *** CUB. CPU    : %1.3e',cubCPU);
fprintf('\n \t *** CUB.REF. CPU: %1.3e',refCPU);
fprintf('\n \n');