function distances = points2distances (intp_points,eval_points,RBF_scale)  

%--------------------------------------------------------------------------
% OBJECT:
% It defines distance matrix from point matrix.
% We store the distance between "points(i,:)" and "points(i,:)" in its 
% component (i,j). 
%--------------------------------------------------------------------------
% INPUT:
% intp_points: N x 2 matrix, describing the RBF centers.
% eval_points: M x 2 matrix, describing the points where the RBFs with
%              centers "intp_points" must be evaluated.
% RBF_scale  : N x 1 matrix, describing the RBF centers.
%--------------------------------------------------------------------------
% OUTPUT:
% distances: M x N matrix, distance matrix (suitably scaled).
%--------------------------------------------------------------------------

if nargin <= 2, RBF_scale=eval_points; eval_points=intp_points; end

%------------------------------------------------------------------
% Evaluating RBF approximant
%------------------------------------------------------------------
evalsquares=sum(eval_points.^2,2);
datasquares=sum(intp_points.^2,2);

[numeval,evaldim]=size(eval_points);
[numdata,datadim]=size(intp_points);

dist_arg=repmat(evalsquares,1,numdata)+...
    repmat(datasquares,1,numeval)'-2*eval_points*intp_points';
distances=sqrt(dist_arg);

if isscalar(RBF_scale) == 1 
    distances=distances/RBF_scale;
else
    % check that "RBF_scale" is a column vector (required default).
    if size(RBF_scale,1) <= size(RBF_scale,2)
        RBF_scale=RBF_scale';
    end
    RBF_scale_mat=repmat(RBF_scale',numeval,1);
    distances=distances./RBF_scale_mat;
end
